@@ -6,7 +6,7 @@ use warnings;
 
 BEGIN {
 	$Error::TypeTiny::AUTHORITY = 'cpan:TOBYINK';
-	$Error::TypeTiny::VERSION   = '1.001_004';
+	$Error::TypeTiny::VERSION   = '1.001_005';
 }
 
 use overload
@@ -60,6 +60,12 @@ sub throw
 		my ($pkg, $func) = ($1 =~ m{^(.+)::(\w+)$});
 		$level++ if caller($level) eq ($pkg||"");
 	}
+	# Moo's Method::Generate::Constructor puts an eval in the stack trace,
+	# that is useless for debugging, so show the stack frame one above.
+	$level++ if (
+		(caller($level))[1] =~ /^\(eval \d+\)$/ and
+		(caller($level))[3] eq '(eval)' # (caller())[3] is $subroutine
+	);
 	@ctxt{qw/ package file line /} = caller($level);
 	
 	my $stack = undef;
