@@ -11,7 +11,7 @@ BEGIN {
 
 BEGIN {
 	$Types::Common::String::AUTHORITY = 'cpan:TOBYINK';
-	$Types::Common::String::VERSION   = '1.001_004';
+	$Types::Common::String::VERSION   = '1.001_005';
 }
 
 use Type::Library -base, -declare => qw(
@@ -60,7 +60,7 @@ $meta->add_type(
 );
 
 NumericCode->coercion->add_type_coercions(
-	NonEmptySimpleStr, q[ do { (my $code = $_) =~ s/[[:punct:]]//g; $code } ],
+	NonEmptySimpleStr, q[ do { (my $code = $_) =~ s/[[:punct:][:space:]]//g; $code } ],
 );
 
 $meta->add_type(
